@@ -4,7 +4,7 @@ from __future__ import unicode_literals
 from django.conf.urls import patterns, url
 
 from .views import HomePageView, FormHorizontalView, FormInlineView, PaginationView, FormWithFilesView, \
-    DefaultFormView
+    DefaultFormView, MiscView, DefaultFormsetView, DefaultFormByFieldView
 
 # Uncomment the next two lines to enable the admin:
 # from django.contrib import admin
@@ -24,9 +24,12 @@ from .views import HomePageView, FormHorizontalView, FormInlineView, PaginationV
 
 urlpatterns = patterns('',
     url(r'^$', HomePageView.as_view(), name='home'),
+    url(r'^formset$', DefaultFormsetView.as_view(), name='formset_default'),
     url(r'^form$', DefaultFormView.as_view(), name='form_default'),
+    url(r'^form_by_field$', DefaultFormByFieldView.as_view(), name='form_by_field'),
     url(r'^form_horizontal$', FormHorizontalView.as_view(), name='form_horizontal'),
     url(r'^form_inline$', FormInlineView.as_view(), name='form_inline'),
-    url(r'^pagination$', PaginationView.as_view(), name='pagination'),
     url(r'^form_with_files$', FormWithFilesView.as_view(), name='form_with_files'),
+    url(r'^pagination$', PaginationView.as_view(), name='pagination'),
+    url(r'^misc$', MiscView.as_view(), name='misc'),
 )
